@@ -30,7 +30,7 @@ N_("I could sure use a backrub right about now..."),
 N_("If you're ever lost and alone in the woods, hug a tree"),
 N_("Just because a crosswalk looks like a hopscotch board doesn't mean it is one"),
 N_("Look both ways before you cross the street"),
-N_("Monitors won't give you Vitamin E -- but sunlight will..."),
+N_("Monitors won't give you Vitamin D -- but sunlight will..."),
 N_("Move card from Waste"),
 N_("Move waste back to stock"),
 N_("Never blow in a dog's ear"),
