@@ -62,6 +62,11 @@ gint current_level;
 guint pixmap_width = 10, pixmap_height = 10;
 */
 
+static struct _pointers {
+	GdkCursor *current;
+	GdkCursor *invisible;
+} pointers = { NULL };
+
 static gint main_loop (gpointer data);
 static gint add_bonus_cb (gpointer data);
 static void render_logo ();
@@ -101,6 +106,22 @@ static GnomeUIInfo main_menu[] = {
 	GNOMEUIINFO_END
 };
 
+void hide_cursor ()
+{
+	if (pointers.current != pointers.invisible) {
+		gdk_window_set_cursor (drawing_area->window, pointers.invisible);
+		pointers.current = pointers.invisible;
+	}
+}
+
+void show_cursor ()
+{
+	if (pointers.current != NULL) {
+		gdk_window_set_cursor (drawing_area->window, NULL);
+		pointers.current = NULL;
+	}
+}
+
 gint game_running ()
 {
 	return (main_id || erase_id || dummy_id || restart_id || paused);
@@ -191,6 +212,7 @@ static gint expose_event_cb (GtkWidget *widget, GdkEventExpose *event)
 static gint key_press_cb (GtkWidget *widget, GdkEventKey *event)
 {
 	gnibbles_keypress_worms (event->keyval);
+	hide_cursor ();
 }
 
 static void draw_board ()
@@ -231,7 +253,8 @@ static gint configure_event_cb (GtkWidget *widget, GdkEventConfigure *event)
 	int i, j;
 
 	gnibbles_load_pixmap();
-	gdk_imlib_free_pixmap (buffer_pixmap);
+	if (buffer_pixmap)
+		gdk_pixmap_unref (buffer_pixmap);
 	buffer_pixmap = gdk_pixmap_new (drawing_area->window,
 					BOARDWIDTH * properties->tilesize,
 					BOARDHEIGHT * properties->tilesize, -1);
@@ -247,17 +270,18 @@ static gint configure_event_cb (GtkWidget *widget, GdkEventConfigure *event)
 static gint new_game_2_cb (GtkWidget *widget, gpointer data)
 {
 	if (!paused) {
-		keyboard_id = gtk_signal_connect (GTK_OBJECT (window),
-				"key_press_event",
-				GTK_SIGNAL_FUNC (key_press_cb), NULL);
-
-		main_id = gtk_timeout_add (GAMEDELAY * properties->gamespeed,
-				(GtkFunction) main_loop, NULL);
-
-		add_bonus_id = gtk_timeout_add (BONUSDELAY *
-				properties->gamespeed,
-				(GtkFunction) add_bonus_cb,
-				NULL);
+		if (!keyboard_id)
+			keyboard_id = gtk_signal_connect (GTK_OBJECT (window),
+					"key_press_event",
+					GTK_SIGNAL_FUNC (key_press_cb), NULL);
+		if (!main_id)
+			main_id = gtk_timeout_add (GAMEDELAY * properties->gamespeed,
+					(GtkFunction) main_loop, NULL);
+		if (!add_bonus_id)
+			add_bonus_id = gtk_timeout_add (BONUSDELAY *
+					properties->gamespeed,
+					(GtkFunction) add_bonus_cb,
+					NULL);
 	}
 
 	dummy_id = 0;
@@ -488,7 +512,7 @@ static gint main_loop (gpointer data)
 		if ((current_level < MAXLEVEL) && !properties->random)
 			current_level++;
 		else if (properties->random) {
-			tmp = rand () % MAXLEVEL;
+			tmp = rand () % MAXLEVEL + 1;
 			while (tmp == current_level)
 				tmp = rand () % MAXLEVEL + 1;
 			current_level = tmp;
@@ -512,9 +536,17 @@ static void set_bg_color ()
 	gdk_image_destroy (tmp_image);
 }
 
+gboolean
+show_cursor_cb (GtkWidget *widget, GdkEventMotion *event, gpointer data)
+{
+        show_cursor ();
+        return FALSE;
+}
+
 static void setup_window ()
 {
 	GtkWidget *label, *hbox;
+	GdkPixmap *cursor_dot_pm;
 
 	window = gnome_app_new ("gnibbles", "GNOME Nibbles");
 	gtk_window_set_policy (GTK_WINDOW (window), FALSE, FALSE, TRUE);
@@ -522,11 +554,21 @@ static void setup_window ()
 	gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 			GTK_SIGNAL_FUNC (quit_cb), NULL);
 
-	gtk_widget_push_visual (gdk_imlib_get_visual ());
-	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+	gtk_widget_push_visual (gdk_rgb_get_visual ());
+	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	drawing_area = gtk_drawing_area_new ();
 
+	cursor_dot_pm = gdk_pixmap_create_from_data(
+		window->window, "\0", 1, 1, 1,
+		&drawing_area->style->fg[GTK_STATE_ACTIVE],
+		&drawing_area->style->bg[GTK_STATE_ACTIVE]);
+
+	pointers.invisible = gdk_cursor_new_from_pixmap (
+		cursor_dot_pm, cursor_dot_pm,
+		&drawing_area->style->fg[GTK_STATE_ACTIVE],
+		&drawing_area->style->bg[GTK_STATE_ACTIVE], 0, 0);
+
 	gtk_widget_pop_colormap ();
 	gtk_widget_pop_visual ();
 
@@ -535,12 +577,18 @@ static void setup_window ()
 	gtk_signal_connect (GTK_OBJECT (drawing_area), "configure_event",
 			GTK_SIGNAL_FUNC (configure_event_cb), NULL);
 
+	gtk_signal_connect (GTK_OBJECT(drawing_area), "motion_notify_event",
+			GTK_SIGNAL_FUNC (show_cursor_cb), NULL);
+
+	gtk_signal_connect (GTK_OBJECT(window), "focus_out_event",
+			GTK_SIGNAL_FUNC (show_cursor_cb), NULL);
+
 	gtk_drawing_area_size (GTK_DRAWING_AREA (drawing_area),
 			BOARDWIDTH*properties->tilesize, BOARDHEIGHT*properties->tilesize);
 	gtk_signal_connect (GTK_OBJECT (drawing_area), "expose_event",
 			GTK_SIGNAL_FUNC (expose_event_cb), NULL);
 	gtk_widget_set_events (drawing_area, GDK_BUTTON_PRESS_MASK |
-			GDK_EXPOSURE_MASK);
+			GDK_EXPOSURE_MASK | GDK_POINTER_MOTION_MASK);
 	gtk_widget_show (drawing_area);
 
 	gnome_app_create_menus (GNOME_APP (window), main_menu);
@@ -591,8 +639,6 @@ int main (int argc, char **argv)
 
 	setup_window ();
 
-	setup_window ();
-
 	gnibbles_load_pixmap ();
 
 	gtk_widget_show (window);
