@@ -23,6 +23,7 @@
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <gdk/gdkkeysyms.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <sys/time.h>
 #include <string.h>
@@ -487,8 +488,7 @@ void load_pixmaps()
 {
 	char *tmp;
 	char *fname;
-	GdkImlibImage *image;
-	GdkVisual *visual;
+	GdkPixbuf *image;
 
 	tmp = g_strconcat("iagno/", tile_set, NULL);
 	fname = gnome_unconditional_pixmap_file(tmp);
@@ -499,16 +499,10 @@ void load_pixmaps()
 		exit(1);
 	}
 
-	image = gdk_imlib_load_image(fname);
-	visual = gdk_imlib_get_visual();
-	if(visual->type != GDK_VISUAL_TRUE_COLOR) {
-		gdk_imlib_set_render_type(RT_PLAIN_PALETTE);
-	}
-	gdk_imlib_render(image, image->rgb_width, image->rgb_height);
-	tiles_pixmap = gdk_imlib_move_image(image);
-	tiles_mask = gdk_imlib_move_mask(image);
+	image = gdk_pixbuf_new_from_file(fname);
+	gdk_pixbuf_render_pixmap_and_mask(image, &tiles_pixmap, &tiles_mask, 127);
 
-	gdk_imlib_destroy_image(image);
+	gdk_pixbuf_unref(image);
 	g_free(fname);
 }
 
@@ -659,8 +653,8 @@ void create_window()
 
 	gnome_app_create_menus(GNOME_APP(window), mainmenu);
 
-	gtk_widget_push_visual (gdk_imlib_get_visual ());
-	gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+	gtk_widget_push_visual (gdk_rgb_get_visual ());
+	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	drawing_area = gtk_drawing_area_new();
 
